//  This Source Code Form is subject to the terms of the Mozilla Public
//  License, v. 2.0. If a copy of the MPL was not distributed with this
//  file, You can obtain one at http://mozilla.org/MPL/2.0/.

library verve;

import 'package:flutter/material.dart';

part 'components.dart';

/// Uses a VerveTheme to reform a ThemeData with relevant colors.
///
/// Also updates ThemeData to use MaterialDesign 2018 specification for
/// text, as opposed to the current 2014 specification.
ThemeData verveSwatch({@required VerveTheme theme, ThemeData base}) {
  if (base == null) base = ThemeData();
  Color bg;
  Color accent;
  Color main;
  base = base.copyWith(
    textTheme: TextTheme(
      display4: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 96.0,
          fontWeight: FontWeight.w300,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: -1.5),
      display3: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 60.0,
          fontWeight: FontWeight.w300,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: -0.5),
      display2: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 48.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.0),
      display1: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 34.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.25),
      headline: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 24.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.0),
      title: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 20.0,
          fontWeight: FontWeight.w500,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.15),
      subhead: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 16.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.15),
      body2: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 14.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.25),
      body1: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 16.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.5),
      button: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 14.0,
          fontWeight: FontWeight.w500,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.75),
      caption: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 12.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.4),
      subtitle: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 14.0,
          fontWeight: FontWeight.w500,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 0.1),
      overline: TextStyle(
          fontFamily: 'Metropolis',
          fontSize: 10.0,
          fontWeight: FontWeight.w400,
          textBaseline: TextBaseline.alphabetic,
          letterSpacing: 1.5),
    ),
  );
  switch (theme) {
    case VerveTheme.amati:
      {
        main = Color(0xff45757D);
        accent = Color(0xff27455C);
        bg = Color(0xffD1E0D3);
        base = base.copyWith(
          primaryColorBrightness: Brightness.dark,
          accentColorBrightness: Brightness.dark,
        );
      }
      break;
    case VerveTheme.blue:
      {
        main = Color(0xff2787B7);
        accent = Color(0xff024669);
        bg = Color(0xffAED3E5);
        base = base.copyWith(
          primaryColorBrightness: Brightness.dark,
          accentColorBrightness: Brightness.dark,
        );
      }
      break;
    case VerveTheme.purple:
      {
        main = Color(0xff73305B);
        accent = Color(0xff272640);
        bg = Color(0xffD9C1C5);
        base = base.copyWith(
          primaryColorBrightness: Brightness.dark,
          accentColorBrightness: Brightness.dark,
        );
      }
      break;
    case VerveTheme.venice:
      {
        main = Color(0xff0396A6);
        accent = Color(0xffF25E5E);
        bg = Color(0xffAEE6D1);
        base = base.copyWith(
          primaryColorBrightness: Brightness.light,
          accentColorBrightness: Brightness.light,
        );
      }
      break;
    case VerveTheme.twilight:
      {
        main = Color(0xffC9D2D9);
        accent = Color(0xff192853);
        bg = Color(0xff0C1A3D);
        base = base.copyWith(
          primaryColorBrightness: Brightness.light,
          accentColorBrightness: Brightness.dark,
        );
      }
      break;
    case VerveTheme.dune:
      {
        main = Color(0xffE6E2AF);
        accent = Color(0xff046380);
        bg = Color(0xffEFECCA);
        base = base.copyWith(
          primaryColorBrightness: Brightness.light,
          accentColorBrightness: Brightness.dark,
        );
      }
      break;
    case VerveTheme.darkMode:
      {
        main = Color(0xff32383D);
        accent = Color(0xff1BC6B4);
        bg = Color(0xff202529);
        base = base.copyWith(
          primaryColorBrightness: Brightness.dark,
          accentColorBrightness: Brightness.light,
        );
      }
      break;
    case VerveTheme.garden:
      {
        main = Color(0xff4BB5C1);
        accent = Color(0xffB5E655);
        bg = Color(0xffEDF7F2);
        base = base.copyWith(
          primaryColorBrightness: Brightness.light,
          accentColorBrightness: Brightness.light,
        );
      }
      break;
    case VerveTheme.navy:
      {
        main = Color(0xff2C3E50);
        accent = Color(0xffFC4349);
        bg = Color(0xffD7DADB);
        base = base.copyWith(
          primaryColorBrightness: Brightness.dark,
          accentColorBrightness: Brightness.light,
        );
      }
      break;
    case VerveTheme.sepia:
      {
        main = Color(0xff1A9481);
        accent = Color(0xff9BCC93);
        bg = Color(0xffFDEEA7);
        base = base.copyWith(
          primaryColorBrightness: Brightness.light,
          accentColorBrightness: Brightness.light,
        );
      }
      break;
    case VerveTheme.material:
      {
        main = Color(0xff6200EE);
        accent = Color(0xff03DAC6);
        bg = Color(0xffFFFFFF);
        base = base.copyWith(
          primaryColorBrightness: Brightness.dark,
          accentColorBrightness: Brightness.light,
        );
      }
      break;
  }
  base = base.copyWith(
    primaryColor: main,
    accentColor: accent,
    splashColor: accent,
    backgroundColor: bg,
    selectedRowColor: accent,
    unselectedWidgetColor: main,
    dialogBackgroundColor: bg,
    cardColor: bg,
    canvasColor: bg,
    bottomAppBarColor: accent,
    scaffoldBackgroundColor: bg,
  );
  return base;
}

///Different themes available for [verveSwatch].
enum VerveTheme {
  material,
  amati,
  venice,
  blue,
  purple,
  twilight,
  dune,
  darkMode,
  garden,
  navy,
  sepia,
}
